@@ -8,7 +8,7 @@ package org.tanukisoftware.wrapper;
  * This software is the proprietary information of Tanuki Software.
  * You shall use it only in accordance with the terms of the
  * license agreement you entered into with Tanuki Software.
- * http://wrapper.tanukisoftware.org/doc/english/licenseOverview.html
+ * http://wrapper.tanukisoftware.com/doc/english/licenseOverview.html
  */
 
 import java.io.ByteArrayInputStream;
@@ -52,6 +52,8 @@ public class WrapperProcessInputStream
     /**
      * Closes the InputStream
      * @throws IOException in case of any file errors
+     * @throws WrapperLicenseError If the function is called other than in
+     *                             the Professional Edition or from a Standalone JVM.
      */
     public void close()
         throws IOException
@@ -86,12 +88,13 @@ public class WrapperProcessInputStream
      * Read a character from the Stream and moves the position in the stream
      * @return single sign from the stream
      * @throws IOException in case the stream has been already closed or any other file error
+     * @throws WrapperLicenseError If the function is called other than in
+     *                             the Professional Edition or from a Standalone JVM.
      */
     public int read()
         throws IOException
     {
-        synchronized( this )
-        {
+        
             if ( !m_closed )
             {
                 return nativeRead( true );
@@ -104,10 +107,10 @@ public class WrapperProcessInputStream
                 }
                 else
                 {
-                    throw new IOException( "Stream is closed." );
+                    throw new IOException(WrapperManager.getRes().getString( "Stream is closed." ) );
                 }
             }
-        }
+        
     }
 
     public int read( byte b[ ]) throws IOException 
@@ -189,9 +192,11 @@ public class WrapperProcessInputStream
             }
             catch( IOException ioe )
             {
-                System.out.println( "WrapperProcessStream encountered a ReadError: ");
+                System.out.println( WrapperManager.getRes().getString( "WrapperProcessStream encountered a ReadError: " ) );
                 ioe.printStackTrace();
             }
         }
     }
 }
+
+  
